@@ -207,8 +207,8 @@ def _get_qemu_convert_luks_cmd(src: str,
                                prefix: Optional[tuple] = None,
                                cipher_spec: Optional[dict] = None,
                                passphrase_file: Optional[str] = None,
-                               src_passphrase_file: Optional[str] = None,
-                               disable_sparse: bool = False) -> list[str]:
+                               src_passphrase_file: Optional[str] = None) \
+        -> list[str]:
     cmd = ['qemu-img', 'convert']
 
     if prefix:
@@ -217,9 +217,6 @@ def _get_qemu_convert_luks_cmd(src: str,
     if cache_mode:
         cmd += ('-t', cache_mode)
 
-    if disable_sparse:
-        cmd += ('-S', '0')
-
     obj1 = ['--object',
             'secret,id=sec1,format=raw,file=%s' % src_passphrase_file]
     obj2 = ['--object',
@@ -245,8 +242,8 @@ def _get_qemu_convert_cmd(src: str,
                           cipher_spec: Optional[dict] = None,
                           passphrase_file: Optional[str] = None,
                           compress: bool = False,
-                          src_passphrase_file: Optional[str] = None,
-                          disable_sparse: bool = False) -> list[str]:
+                          src_passphrase_file: Optional[str] = None) \
+        -> list[str]:
     if src_passphrase_file is not None:
         if passphrase_file is None:
             message = _("Can't create unencrypted volume %(format)s "
@@ -265,8 +262,7 @@ def _get_qemu_convert_cmd(src: str,
             prefix=None,
             cipher_spec=cipher_spec,
             passphrase_file=passphrase_file,
-            src_passphrase_file=src_passphrase_file,
-            disable_sparse=disable_sparse)
+            src_passphrase_file=src_passphrase_file)
 
     if out_format == 'vhd':
         # qemu-img still uses the legacy vpc name
@@ -280,9 +276,6 @@ def _get_qemu_convert_cmd(src: str,
     if cache_mode:
         cmd += ('-t', cache_mode)
 
-    if disable_sparse:
-        cmd += ('-S', '0')
-
     if CONF.image_compress_on_upload and compress:
         if out_format in COMPRESSIBLE_IMAGE_FORMATS:
             cmd += ('-c',)
@@ -347,8 +340,7 @@ def _convert_image(prefix: tuple,
                    cipher_spec: Optional[dict] = None,
                    passphrase_file: Optional[str] = None,
                    compress: bool = False,
-                   src_passphrase_file: Optional[str] = None,
-                   disable_sparse: bool = False) -> None:
+                   src_passphrase_file: Optional[str] = None) -> None:
     """Convert image to other format.
 
     NOTE: If the qemu-img convert command fails and this function raises an
@@ -397,8 +389,7 @@ def _convert_image(prefix: tuple,
                                 cipher_spec=cipher_spec,
                                 passphrase_file=passphrase_file,
                                 compress=compress,
-                                src_passphrase_file=src_passphrase_file,
-                                disable_sparse=disable_sparse)
+                                src_passphrase_file=src_passphrase_file)
 
     start_time = timeutils.utcnow()
 
@@ -459,8 +450,7 @@ def convert_image(source: str,
                   compress: bool = False,
                   src_passphrase_file: Optional[str] = None,
                   image_id: Optional[str] = None,
-                  data: Optional[imageutils.QemuImgInfo] = None,
-                  disable_sparse: bool = False) -> None:
+                  data: Optional[imageutils.QemuImgInfo] = None) -> None:
     """Convert image to other format.
 
     NOTE: If the qemu-img convert command fails and this function raises an
@@ -499,8 +489,7 @@ def convert_image(source: str,
                        cipher_spec=cipher_spec,
                        passphrase_file=passphrase_file,
                        compress=compress,
-                       src_passphrase_file=src_passphrase_file,
-                       disable_sparse=disable_sparse)
+                       src_passphrase_file=src_passphrase_file)
 
 
 def resize_image(source: str,
@@ -823,13 +812,11 @@ def fetch_to_vhd(context: context.RequestContext,
                  volume_subformat: Optional[str] = None,
                  user_id: Optional[str] = None,
                  project_id: Optional[str] = None,
-                 run_as_root: bool = True,
-                 disable_sparse: bool = False) -> None:
+                 run_as_root: bool = True) -> None:
     fetch_to_volume_format(context, image_service, image_id, dest, 'vpc',
                            blocksize, volume_subformat=volume_subformat,
                            user_id=user_id, project_id=project_id,
-                           run_as_root=run_as_root,
-                           disable_sparse=disable_sparse)
+                           run_as_root=run_as_root)
 
 
 def fetch_to_raw(context: context.RequestContext,
@@ -840,12 +827,10 @@ def fetch_to_raw(context: context.RequestContext,
                  user_id: Optional[str] = None,
                  project_id: Optional[str] = None,
                  size: Optional[int] = None,
-                 run_as_root: bool = True,
-                 disable_sparse: bool = False) -> None:
+                 run_as_root: bool = True) -> None:
     fetch_to_volume_format(context, image_service, image_id, dest, 'raw',
                            blocksize, user_id=user_id, project_id=project_id,
-                           size=size, run_as_root=run_as_root,
-                           disable_sparse=disable_sparse)
+                           size=size, run_as_root=run_as_root)
 
 
 def check_image_conversion_disable(disk_format, volume_format, image_id,
@@ -880,8 +865,7 @@ def fetch_to_volume_format(context: context.RequestContext,
                            user_id: Optional[str] = None,
                            project_id: Optional[str] = None,
                            size: Optional[int] = None,
-                           run_as_root: bool = True,
-                           disable_sparse: bool = False) -> None:
+                           run_as_root: bool = True) -> None:
     qemu_img = True
     image_meta = image_service.show(context, image_id)
 
@@ -996,8 +980,16 @@ def fetch_to_volume_format(context: context.RequestContext,
                       src_format=disk_format,
                       run_as_root=run_as_root,
                       image_id=image_id,
-                      data=data,
-                      disable_sparse=disable_sparse)
+                      data=data)
+
+
+@contextlib.contextmanager
+def chown_if_needed(volume_path: str) -> Generator[None, None, None]:
+    if os.name == 'nt' or os.access(volume_path, os.R_OK):
+        yield
+    else:
+        with utils.temporary_chown(volume_path):
+            yield
 
 
 def upload_volume(context: context.RequestContext,
@@ -1020,19 +1012,12 @@ def upload_volume(context: context.RequestContext,
         if (image_meta['disk_format'] == volume_format):
             LOG.debug("%s was %s, no need to convert to %s",
                       image_id, volume_format, image_meta['disk_format'])
-            if os.name == 'nt' or os.access(volume_path, os.R_OK):
+            with chown_if_needed(volume_path):
                 with open(volume_path, 'rb') as image_file:
                     image_service.update(context, image_id, {},
                                          tpool.Proxy(image_file),
                                          store_id=store_id,
                                          base_image_ref=base_image_ref)
-            else:
-                with utils.temporary_chown(volume_path):
-                    with open(volume_path, 'rb') as image_file:
-                        image_service.update(context, image_id, {},
-                                             tpool.Proxy(image_file),
-                                             store_id=store_id,
-                                             base_image_ref=base_image_ref)
             return
 
     with temporary_file(prefix='vol_upload_') as tmp:
