@@ -24,6 +24,7 @@ import fixtures
 from oslo_config import cfg
 from oslo_policy import policy as oslo_policy
 from oslo_privsep import daemon as privsep_daemon
+from sqlalchemy import exc as sqla_exc
 
 import cinder.policy
 
@@ -123,7 +124,10 @@ class WarningsFixture(fixtures.Fixture):
     """Filters out warnings during test runs."""
 
     def setUp(self):
-        super(WarningsFixture, self).setUp()
+        super().setUp()
+
+        self._original_warning_filters = warnings.filters[:]
+
         # NOTE(sdague): Make deprecation warnings only happen once. Otherwise
         # this gets kind of crazy given the way that upstream python libs use
         # this.
@@ -136,7 +140,74 @@ class WarningsFixture(fixtures.Fixture):
             message='Policy enforcement is depending on the value of is_admin.'
                     ' This key is deprecated. Please update your policy '
                     'file to use the standard policy values.')
-        self.addCleanup(warnings.resetwarnings)
+
+        # We can't do anything about this outside of cinder
+        warnings.filterwarnings(
+            'ignore',
+            message='distutils Version classes are deprecated. .*',
+            category=DeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            message='the imp module is deprecated in favour of importlib',
+            category=DeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            message='invalid escape sequence',
+            category=DeprecationWarning,
+        )
+        warnings.filterwarnings(
+            'error',
+            message='invalid escape sequence',
+            category=DeprecationWarning,
+            module='cinder',
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            message='Policy ".*":".*" was deprecated in ',
+            module='oslo_policy',
+            category=UserWarning,
+        )
+
+        # Enable deprecation warnings for cinder itself to capture upcoming
+        # SQLAlchemy changes
+
+        warnings.filterwarnings(
+            'ignore',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'error',
+            module='cinder',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        # ...but filter everything out until we get around to fixing them
+        # TODO: Fix all of these
+
+        warnings.filterwarnings(
+            'ignore',
+            module='cinder',
+            message='The current statement is being autocommitted using ',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        warnings.filterwarnings(
+            'ignore',
+            module='cinder',
+            message='The Session.begin.subtransactions flag is deprecated ',
+            category=sqla_exc.SADeprecationWarning,
+        )
+
+        self.addCleanup(self._reset_warning_filters)
+
+    def _reset_warning_filters(self):
+        warnings.filters[:] = self._original_warning_filters
 
 
 class UnHelperfulClientChannel(privsep_daemon._ClientChannel):
