@@ -22,7 +22,9 @@ from cinder.volume.drivers.netapp.dataontap.client import api as netapp_api
 VOLUME_ID = 'f10d1a84-9b7b-427e-8fec-63c48b509a56'
 LUN_ID = 'ee6b4cc7-477b-4016-aa0c-7127b4e3af86'
 LUN_HANDLE = 'fake_lun_handle'
+NAMESPACE_HANDLE = 'fake_namespace_handle'
 LUN_NAME = 'lun1'
+NAMESPACE_NAME = 'namespace1'
 LUN_SIZE = 3
 LUN_TABLE = {LUN_NAME: None}
 SIZE = 1024
@@ -40,6 +42,7 @@ AGGREGATE = 'aggr1'
 FLEXVOL = 'openstack-flexvol'
 NFS_FILE_PATH = 'nfsvol'
 PATH = '/vol/%s/%s' % (POOL_NAME, LUN_NAME)
+PATH_NAMESPACE = '/vol/%s/%s' % (POOL_NAME, NAMESPACE_NAME)
 IMAGE_FILE_ID = 'img-cache-imgid'
 PROVIDER_LOCATION = 'fake_provider_location'
 NFS_HOST = 'nfs-host1'
@@ -65,6 +68,12 @@ LUN_METADATA = {
     'Qtree': None,
     'Volume': POOL_NAME,
 }
+NAMESPACE_METADATA = {
+    'OsType': None,
+    'Path': PATH_NAMESPACE,
+    'Qtree': None,
+    'Volume': POOL_NAME,
+}
 VOLUME = {
     'name': LUN_NAME,
     'size': SIZE,
@@ -72,6 +81,13 @@ VOLUME = {
     'host': HOST_STRING,
     'attach_status': DETACHED,
 }
+NAMESPACE_VOLUME = {
+    'name': NAMESPACE_NAME,
+    'size': SIZE,
+    'id': VOLUME_ID,
+    'host': HOST_STRING,
+    'attach_status': DETACHED,
+}
 NFS_VOLUME = {
     'name': NFS_FILE_PATH,
     'size': SIZE,
@@ -213,6 +229,12 @@ IGROUP1 = {
     'initiator-group-name': IGROUP1_NAME,
 }
 
+CUSTOM_IGROUP = {
+    'initiator-group-os-type': 'linux',
+    'initiator-group-type': 'fcp',
+    'initiator-group-name': 'node1',
+}
+
 ISCSI_VOLUME = {
     'name': 'fake_volume',
     'id': 'fake_id',
@@ -269,8 +291,9 @@ IGROUP1 = {'initiator-group-os-type': 'linux',
 QOS_SPECS = {}
 EXTRA_SPECS = {}
 MAX_THROUGHPUT = '21734278B/s'
-MIN_IOPS = '256IOPS'
-MAX_IOPS = '512IOPS'
+MIN_IOPS = '256iops'
+MAX_IOPS = '512iops'
+MAX_BPS = '1000000B/s'
 QOS_POLICY_GROUP_NAME = 'fake_qos_policy_group_name'
 
 QOS_POLICY_GROUP_INFO_LEGACY = {
@@ -284,6 +307,11 @@ QOS_POLICY_GROUP_SPEC = {
     'policy_name': QOS_POLICY_GROUP_NAME,
 }
 
+QOS_POLICY_GROUP_SPEC_BPS = {
+    'max_throughput': MAX_BPS,
+    'policy_name': QOS_POLICY_GROUP_NAME,
+}
+
 QOS_POLICY_GROUP_SPEC_MAX = {
     'max_throughput': MAX_THROUGHPUT,
     'policy_name': QOS_POLICY_GROUP_NAME,
@@ -337,6 +365,8 @@ VOLUME_PATH = '/vol/%s/%s' % (NETAPP_VOLUME, VOLUME_NAME)
 MOUNT_PATH = '168.10.16.11:/' + VOLUME_ID
 SNAPSHOT_NAME = 'fake_snapshot_name'
 SNAPSHOT_LUN_HANDLE = 'fake_snapshot_lun_handle'
+SNAPSHOT_NAMESPACE_HANDLE = 'fake_snapshot_namespace_handle'
+
 SNAPSHOT_MOUNT = '/fake/mount/path'
 
 SNAPSHOT = {
@@ -369,6 +399,21 @@ LUN_WITH_METADATA = {
     }
 }
 
+NAMESPACE_WITH_METADATA = {
+    'handle': 'vserver_fake:/vol/fake_flexvol/volume-fake-uuid',
+    'name': 'volume-fake-uuid',
+    'size': 20971520,
+    'metadata': {
+        'Vserver': 'vserver_fake',
+        'Volume': 'fake_flexvol',
+        'Qtree': None,
+        'Path': '/vol/fake_flexvol/volume-fake-uuid',
+        'OsType': 'linux',
+        'SpaceReserved': 'false',
+        'UUID': 'fake-uuid'
+    }
+}
+
 VOLUME_REF = {'name': 'fake_vref_name', 'size': 42}
 
 FAKE_CMODE_VOLUMES = ['open123', 'mixed', 'open321']
@@ -411,6 +456,19 @@ FAKE_LUN = netapp_api.NaElement.create_node_with_children(
        'volume': 'fakeLUN',
        'vserver': 'fake_vserver'})
 
+FAKE_LUN_GET_ITER_RESULT = [
+    {
+        'Vserver': 'fake_vserver',
+        'Volume': 'fake_volume',
+        'Size': 123,
+        'Qtree': 'fake_qtree',
+        'Path': 'fake_path',
+        'OsType': 'fake_os',
+        'SpaceReserved': 'true',
+        'UUID': 'fake-uuid',
+    },
+]
+
 CG_VOLUME_NAME = 'fake_cg_volume'
 CG_GROUP_NAME = 'fake_consistency_group'
 CG_POOL_NAME = 'cdot'
@@ -698,6 +756,7 @@ test_volume.state = {
 test_volume.qos = {'qos_policy_group': None}
 test_volume.host = 'fakehost@backbackend#fakepool'
 test_volume.name = 'fakename'
+test_volume.size = SIZE
 
 
 class test_snapshot(object):
@@ -734,12 +793,222 @@ def get_fake_net_interface_get_iter_response():
 
 
 def get_fake_ifs():
-    list_of_ifs = [
-        etree.XML("""<net-interface-info>
-        <address>FAKE_IP</address></net-interface-info>"""),
-        etree.XML("""<net-interface-info>
-        <address>FAKE_IP2</address></net-interface-info>"""),
-        etree.XML("""<net-interface-info>
-        <address>FAKE_IP3</address></net-interface-info>"""),
-    ]
-    return [netapp_api.NaElement(el) for el in list_of_ifs]
+    return [{'vserver': VSERVER_NAME}]
+
+
+AFF_SYSTEM_NODE_GET_ITER_RESPONSE_REST = {
+    "records": [
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-525400",
+            "name": "aff-node1",
+            "model": "AFFA400",
+            "is_all_flash_optimized": True,
+            "is_all_flash_select_optimized": False,
+            "_links": {
+                "self": {
+                    "href": "/api/cluster/nodes/9eff6c76-fc13-11ea-8799-525400"
+                }
+            }
+        },
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-52540006bba9",
+            "name": "aff-node2",
+            "model": "AFFA400",
+            "is_all_flash_optimized": True,
+            "is_all_flash_select_optimized": False,
+            "_links": {
+                "self": {
+                    "href": "/api/cluster/nodes/9eff6c76-fc13-11ea-8799-525400"
+                }
+            }
+        }
+    ],
+    "num_records": 2,
+    "_links": {
+        "self": {
+            "href": "/api/cluster/nodes?fields=model,name,"
+                    "is_all_flash_optimized,is_all_flash_select_optimized"
+        }
+    }
+}
+
+FAS_SYSTEM_NODE_GET_ITER_RESPONSE_REST = {
+    "records": [
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-52540006bba9",
+            "name": "fas-node1",
+            "model": "FAS2554",
+            "is_all_flash_optimized": False,
+            "is_all_flash_select_optimized": False,
+            "_links": {
+                "self": {
+                    "href": "/api/cluster/nodes/9eff6c76-fc13-11ea-8799-525400"
+                }
+            }
+        },
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-52540006bba9",
+            "name": "fas-node2",
+            "model": "FAS2554",
+            "is_all_flash_optimized": False,
+            "is_all_flash_select_optimized": False,
+            "_links": {
+                "self": {
+                    "href": "/api/cluster/nodes/9eff6c76-fc13-11ea-8799-525400"
+                }
+            }
+        }
+    ],
+    "num_records": 2,
+    "_links": {
+        "self": {
+            "href": "/api/cluster/nodes?fields=model,name,"
+                    "is_all_flash_optimized,is_all_flash_select_optimized"
+        }
+    }
+}
+
+HYBRID_SYSTEM_NODE_GET_ITER_RESPONSE_REST = {
+    "records": [
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-52540006bba9",
+            "name": "select-node",
+            "model": "FDvM300",
+            "is_all_flash_optimized": False,
+            "is_all_flash_select_optimized": True,
+            "_links": {
+                "self": {
+                    "href": "/api/cluster/nodes/9eff6c76-fc13-11ea-8799-525400"
+                }
+            }
+        },
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-52540006bba9",
+            "name": "c190-node",
+            "model": "AFF-C190",
+            "is_all_flash_optimized": True,
+            "is_all_flash_select_optimized": False,
+            "_links": {
+                "self": {
+                    "href": "/api/cluster/nodes/9eff6c76-fc13-11ea-8799-525400"
+                }
+            }
+        }
+    ],
+    "num_records": 2,
+    "_links": {
+        "self": {
+            "href": "/api/cluster/nodes?fields=model,name,"
+                    "is_all_flash_optimized,is_all_flash_select_optimized"
+        }
+    }
+}
+
+QOS_POLICY_BY_NAME_RESPONSE_REST = {
+    "records": [
+        {
+            "uuid": "9eff6c76-fc13-11ea-8799-52540006bba9",
+            "name": "openstack-cd-uuid",
+            "_links": {
+                "self": {
+                    "href": "/api/storage/qos/policies/"
+                            "9eff6c76-fc13-11ea-8799-52540006bba9"
+                }
+            }
+        }
+    ],
+    "num_records": 1,
+    "_links": {
+        "self": {
+            "href": "/api/storage/qos/policies?fields=name"
+        }
+    }
+}
+
+QOS_SPECS_REST = {}
+MAX_THROUGHPUT_REST = '21734278'
+MIN_IOPS_REST = '256'
+MAX_IOPS_REST = '512'
+MAX_BPS_REST = '1'
+
+QOS_POLICY_GROUP_INFO_LEGACY_REST = {
+    'legacy': 'legacy-' + QOS_POLICY_GROUP_NAME,
+    'spec': None,
+}
+
+QOS_POLICY_GROUP_SPEC_REST = {
+    'min_throughput': MIN_IOPS_REST,
+    'max_throughput': MAX_IOPS_REST,
+    'policy_name': QOS_POLICY_GROUP_NAME,
+}
+
+QOS_POLICY_GROUP_API_ARGS_REST = {
+    'name': QOS_POLICY_GROUP_NAME,
+    'svm': {
+        'name': VSERVER_NAME
+    },
+    'fixed': {
+        'max_throughput_iops': int(MAX_IOPS_REST),
+        'min_throughput_iops': int(MIN_IOPS_REST)
+    }
+}
+
+QOS_POLICY_GROUP_API_ARGS_REST_BPS = {
+    'name': QOS_POLICY_GROUP_NAME,
+    'svm': {
+        'name': VSERVER_NAME
+    },
+    'fixed': {
+        'max_throughput_mbps': int(MAX_BPS_REST),
+    }
+}
+
+QOS_POLICY_GROUP_SPEC_MAX_REST = {
+    'max_throughput': MAX_THROUGHPUT_REST,
+    'policy_name': QOS_POLICY_GROUP_NAME,
+}
+
+EXPECTED_IOPS_PER_GB_REST = '128'
+PEAK_IOPS_PER_GB_REST = '512'
+PEAK_IOPS_ALLOCATION_REST = 'used-space'
+EXPECTED_IOPS_ALLOCATION_REST = 'used-space'
+ABSOLUTE_MIN_IOPS_REST = '75'
+BLOCK_SIZE_REST = 'ANY'
+ADAPTIVE_QOS_SPEC_REST = {
+    'policy_name': QOS_POLICY_GROUP_NAME,
+    'expected_iops': EXPECTED_IOPS_PER_GB_REST,
+    'expected_iops_allocation': EXPECTED_IOPS_ALLOCATION_REST,
+    'peak_iops': PEAK_IOPS_PER_GB_REST,
+    'peak_iops_allocation': PEAK_IOPS_ALLOCATION_REST,
+    'absolute_min_iops': ABSOLUTE_MIN_IOPS_REST,
+    'block_size': BLOCK_SIZE_REST,
+}
+
+ADAPTIVE_QOS_API_ARGS_REST = {
+    'name': QOS_POLICY_GROUP_NAME,
+    'svm': {
+        'name': VSERVER_NAME
+    },
+    'adaptive': {
+        'absolute_min_iops': int(ABSOLUTE_MIN_IOPS_REST),
+        'expected_iops': int(EXPECTED_IOPS_PER_GB_REST),
+        'expected_iops_allocation': EXPECTED_IOPS_ALLOCATION_REST,
+        'peak_iops': int(PEAK_IOPS_PER_GB_REST),
+        'peak_iops_allocation': PEAK_IOPS_ALLOCATION_REST,
+        'block_size': BLOCK_SIZE_REST,
+    }
+}
+
+QOS_POLICY_GROUP_INFO_REST = {
+    'legacy': None, 'spec': QOS_POLICY_GROUP_SPEC_REST}
+QOS_POLICY_GROUP_INFO_MAX_REST = {
+    'legacy': None, 'spec': QOS_POLICY_GROUP_SPEC_MAX_REST}
+ADAPTIVE_QOS_POLICY_GROUP_INFO_REST = {
+    'legacy': None,
+    'spec': ADAPTIVE_QOS_SPEC_REST,
+}
+
+REST_FIELDS = 'uuid,name,style'
+SUBSYSTEM = 'openstack-fake-subsystem'
+HOST_NQN = 'nqn.1992-01.example.com:string'
+TARGET_NQN = 'nqn.1992-01.example.com:target'
