@@ -29,10 +29,10 @@ from oslo_utils import units
 from cinder import context
 from cinder import exception
 from cinder.image import image_utils
-from cinder import test
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit import fake_snapshot
 from cinder.tests.unit import fake_volume
+from cinder.tests.unit import test
 from cinder.tests.unit import utils as test_utils
 from cinder.tests.unit.windows import db_fakes
 from cinder.volume import configuration as conf
@@ -82,7 +82,7 @@ class TestWindowsISCSIDriver(test.TestCase):
         self._driver.configuration = mock.Mock()
         self._driver.configuration.target_port = iscsi_port
         self._driver.configuration.target_ip_address = requested_ips[0]
-        self._driver.configuration.iscsi_secondary_ip_addresses = (
+        self._driver.configuration.target_secondary_ip_addresses = (
             requested_ips[1:])
 
         self._driver._tgt_utils.get_portal_locations.return_value = (
