@@ -20,8 +20,8 @@ import random
 
 from oslo_log import log as logging
 from oslo_utils import strutils
-import six
 
+from cinder.common import constants
 from cinder import exception
 from cinder.i18n import _
 from cinder import interface
@@ -315,7 +315,7 @@ class PowerMaxISCSIDriver(san.SanISCSIDriver):
         except KeyError as e:
             exception_message = (_("Cannot get iSCSI ipaddresses, multipath "
                                    "flag, or hostlunid. Exception is %(e)s.")
-                                 % {'e': six.text_type(e)})
+                                 % {'e': str(e)})
             raise exception.VolumeBackendAPIException(
                 message=exception_message)
 
@@ -454,7 +454,7 @@ class PowerMaxISCSIDriver(san.SanISCSIDriver):
         """Retrieve stats info from volume group."""
         LOG.debug("Updating volume stats")
         data = self.common.update_volume_stats()
-        data['storage_protocol'] = 'iSCSI'
+        data['storage_protocol'] = constants.ISCSI
         data['driver_version'] = self.VERSION
         self._stats = data
 
