@@ -35,6 +35,7 @@ Supports XtremIO version 2.4 and up.
   1.0.13 - add support for iSCSI IPv6
 """
 
+import http.client as http_client
 import json
 import math
 import random
@@ -46,9 +47,8 @@ from oslo_utils import netutils
 from oslo_utils import strutils
 from oslo_utils import units
 import requests
-import six
-from six.moves import http_client
 
+from cinder.common import constants
 from cinder import context
 from cinder import exception
 from cinder.i18n import _
@@ -175,7 +175,7 @@ class XtremIOClient(object):
                     verify=self.verify, auth=(self.configuration.san_login,
                                               self.configuration.san_password))
             except requests.exceptions.RequestException as exc:
-                msg = (_('Exception: %s') % six.text_type(exc))
+                msg = (_('Exception: %s') % str(exc))
                 raise exception.VolumeDriverException(message=msg)
 
             if (http_client.OK <= response.status_code <
@@ -723,7 +723,7 @@ class XtremIOVolumeDriver(san.SanDriver):
 
     def extend_volume(self, volume, new_size):
         """Extend an existing volume's size."""
-        data = {'vol-size': six.text_type(new_size) + 'g'}
+        data = {'vol-size': str(new_size) + 'g'}
         try:
             self.client.req('volumes', 'PUT', data, name=volume['id'])
         except exception.NotFound:
@@ -769,8 +769,8 @@ class XtremIOVolumeDriver(san.SanDriver):
             ig_indexes = self._get_ig_indexes_from_initiators(connector)
 
         for ig_idx in ig_indexes:
-            lm_name = '%s_%s_%s' % (six.text_type(vol['index']),
-                                    six.text_type(ig_idx),
+            lm_name = '%s_%s_%s' % (str(vol['index']),
+                                    str(ig_idx),
                                     tg_index)
             LOG.debug('Removing lun map %s.', lm_name)
             try:
@@ -1101,7 +1101,7 @@ class XtremIOISCSIDriver(XtremIOVolumeDriver, driver.ISCSIDriver):
 
     def __init__(self, *args, **kwargs):
         super(XtremIOISCSIDriver, self).__init__(*args, **kwargs)
-        self.protocol = 'iSCSI'
+        self.protocol = constants.ISCSI
 
     def _add_auth(self, data, login_chap, discovery_chap):
         login_passwd, discovery_passwd = None, None
@@ -1240,7 +1240,7 @@ class XtremIOFCDriver(XtremIOVolumeDriver,
 
     def __init__(self, *args, **kwargs):
         super(XtremIOFCDriver, self).__init__(*args, **kwargs)
-        self.protocol = 'FC'
+        self.protocol = constants.FC
         self._targets = None
 
     def get_targets(self):
