@@ -1,4 +1,4 @@
-# Copyright (C) 2020, 2021, Hitachi, Ltd.
+# Copyright (C) 2020, 2023, Hitachi, Ltd.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -21,6 +21,7 @@ from oslo_utils import excutils
 from cinder import interface
 from cinder.volume import driver
 from cinder.volume.drivers.hitachi import hbsd_common as common
+from cinder.volume.drivers.hitachi import hbsd_replication as replication
 from cinder.volume.drivers.hitachi import hbsd_rest as rest
 from cinder.volume.drivers.hitachi import hbsd_rest_iscsi as rest_iscsi
 from cinder.volume.drivers.hitachi import hbsd_utils as utils
@@ -51,6 +52,8 @@ _DRIVER_INFO = {
     'nvol_ldev_type': utils.NVOL_LDEV_TYPE,
     'target_iqn_suffix': utils.TARGET_IQN_SUFFIX,
     'pair_attr': utils.PAIR_ATTR,
+    'mirror_attr': utils.MIRROR_ATTR,
+    'driver_impl_class': rest_iscsi.HBSDRESTISCSI,
 }
 
 
@@ -71,6 +74,12 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
         2.2.1 - Make the parameters name variable for supporting OEM storages.
         2.2.2 - Add Target Port Assignment.
         2.2.3 - Add port scheduler.
+        2.3.0 - Support multi pool.
+        2.3.1 - Update retype and support storage assisted migration.
+        2.3.2 - Add specifies format of the names HostGroups/iSCSI Targets.
+        2.3.3 - Add GAD volume support.
+        2.3.4 - Support data deduplication and compression.
+        2.3.5 - Fix key error when backend is down.
 
     """
 
@@ -79,6 +88,8 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
     # ThirdPartySystems wiki page
     CI_WIKI_NAME = utils.CI_WIKI_NAME
 
+    driver_info = dict(_DRIVER_INFO)
+
     def __init__(self, *args, **kwargs):
         """Initialize instance variables."""
         utils.output_log(MSG.DRIVER_INITIALIZATION_START,
@@ -87,11 +98,23 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
         super(HBSDISCSIDriver, self).__init__(*args, **kwargs)
 
         self.configuration.append_config_values(common.COMMON_VOLUME_OPTS)
+        self.configuration.append_config_values(common.COMMON_PAIR_OPTS)
+        self.configuration.append_config_values(common.COMMON_NAME_OPTS)
+        self.configuration.append_config_values(
+            replication.COMMON_MIRROR_OPTS)
         os.environ['LANG'] = 'C'
-        self.common = self._init_common(self.configuration, kwargs.get('db'))
-
-    def _init_common(self, conf, db):
-        return rest_iscsi.HBSDRESTISCSI(conf, _DRIVER_INFO, db)
+        kwargs.setdefault('driver_info', _DRIVER_INFO)
+        self.driver_info = dict(kwargs['driver_info'])
+        self.driver_info['driver_class'] = self.__class__
+        if self.configuration.safe_get('hitachi_mirror_storage_id'):
+            self.common = replication.HBSDREPLICATION(
+                self.configuration, self.driver_info, kwargs.get('db'))
+        elif not hasattr(self, '_init_common'):
+            self.common = self.driver_info['driver_impl_class'](
+                self.configuration, self.driver_info, kwargs.get('db'))
+        else:
+            self.common = self._init_common(
+                self.configuration, kwargs.get('db'))
 
     @staticmethod
     def get_driver_options():
@@ -101,7 +124,16 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
               ['driver_ssl_cert_verify', 'driver_ssl_cert_path',
                'san_api_port', ]))
         return (common.COMMON_VOLUME_OPTS +
+                common.COMMON_PAIR_OPTS +
+                common.COMMON_NAME_OPTS +
                 rest.REST_VOLUME_OPTS +
+                rest.REST_PAIR_OPTS +
+                replication._REP_OPTS +
+                replication.COMMON_MIRROR_OPTS +
+                replication.ISCSI_MIRROR_OPTS +
+                replication.REST_MIRROR_OPTS +
+                replication.REST_MIRROR_API_OPTS +
+                replication.REST_MIRROR_SSL_OPTS +
                 additional_opts)
 
     def check_for_setup_error(self):
@@ -144,9 +176,10 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
         """Return properties, capabilities and current states of the driver."""
         data = self.common.update_volume_stats()
         if 'pools' in data:
-            data["pools"][0]["filter_function"] = self.get_filter_function()
-            data["pools"][0]["goodness_function"] = (
-                self.get_goodness_function())
+            for pool in data['pools']:
+                pool["filter_function"] = self.get_filter_function()
+                pool["goodness_function"] = (
+                    self.get_goodness_function())
         self._stats = data
 
     @volume_utils.trace
@@ -177,7 +210,7 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
     @volume_utils.trace
     def manage_existing_get_size(self, volume, existing_ref):
         """Return the size[GB] of the specified volume."""
-        return self.common.manage_existing_get_size(existing_ref)
+        return self.common.manage_existing_get_size(volume, existing_ref)
 
     @volume_utils.trace
     def unmanage(self, volume):
@@ -240,7 +273,12 @@ class HBSDISCSIDriver(driver.ISCSIDriver):
     @volume_utils.trace
     def retype(self, ctxt, volume, new_type, diff, host):
         """Retype the specified volume."""
-        return self.common.retype()
+        return self.common.retype(ctxt, volume, new_type, diff, host)
+
+    @volume_utils.trace
+    def migrate_volume(self, ctxt, volume, host):
+        """Migrate the specified volume."""
+        return self.common.migrate_volume(volume, host)
 
     def backup_use_temp_snapshot(self):
         return True
