@@ -38,6 +38,7 @@ except ImportError:
 from oslo_log import log as logging
 from oslo_utils.excutils import save_and_reraise_exception
 
+from cinder.common import constants
 from cinder import coordination
 from cinder import exception
 from cinder.i18n import _
@@ -128,17 +129,18 @@ class HPE3PARISCSIDriver(hpebasedriver.HPE3PARDriverBase):
         4.0.4 - Added Peer Persistence feature
         4.0.5 - Added Primera array check. bug #1849525
         4.0.6 - Allow iSCSI support for Primera 4.2 onwards
+        4.0.7 - Use vlan iscsi ips. Bug #2015034
 
     """
 
-    VERSION = "4.0.6"
+    VERSION = "4.0.7"
 
     # The name of the CI wiki page.
     CI_WIKI_NAME = "HPE_Storage_CI"
 
     def __init__(self, *args, **kwargs):
         super(HPE3PARISCSIDriver, self).__init__(*args, **kwargs)
-        self.protocol = 'iSCSI'
+        self.protocol = constants.ISCSI
 
     def _do_setup(self, common):
         client_obj = common.client
@@ -163,6 +165,13 @@ class HPE3PARISCSIDriver(hpebasedriver.HPE3PARDriverBase):
         finally:
             self._logout(common)
 
+    def _update_dicts(self, temp_iscsi_ip, iscsi_ip_list, ip, port):
+        ip_port = temp_iscsi_ip[ip]['ip_port']
+        iscsi_ip_list[ip] = {'ip_port': ip_port,
+                             'nsp': port['nsp'],
+                             'iqn': port['iSCSIName']}
+        del temp_iscsi_ip[ip]
+
     def initialize_iscsi_ports(self, common,
                                remote_target=None, remote_client=None):
         # map iscsi_ip-> ip_port
@@ -201,15 +210,20 @@ class HPE3PARISCSIDriver(hpebasedriver.HPE3PARDriverBase):
         # when found, add the valid iSCSI ip, ip port, iqn and nsp
         # to the iSCSI IP dictionary
         iscsi_ports = common.get_active_iscsi_target_ports(remote_client)
+        LOG.debug("iscsi_ports: %(iscsi_ports)s", {'iscsi_ports': iscsi_ports})
 
         for port in iscsi_ports:
             ip = port['IPAddr']
             if ip in temp_iscsi_ip:
-                ip_port = temp_iscsi_ip[ip]['ip_port']
-                iscsi_ip_list[ip] = {'ip_port': ip_port,
-                                     'nsp': port['nsp'],
-                                     'iqn': port['iSCSIName']}
-                del temp_iscsi_ip[ip]
+                self._update_dicts(temp_iscsi_ip, iscsi_ip_list, ip, port)
+
+            if 'iSCSIVlans' in port:
+                for vip in port['iSCSIVlans']:
+                    ip = vip['IPAddr']
+                    if ip in temp_iscsi_ip:
+                        LOG.debug("vlan ip: %(ip)s", {'ip': ip})
+                        self._update_dicts(temp_iscsi_ip, iscsi_ip_list,
+                                           ip, port)
 
         # if the single value iscsi_ip_address option is still in the
         # temp dictionary it's because it defaults to $my_ip which doesn't
@@ -236,6 +250,44 @@ class HPE3PARISCSIDriver(hpebasedriver.HPE3PARDriverBase):
             self.iscsi_ips[common._client_conf['hpe3par_api_url']] = (
                 iscsi_ip_list)
 
+    def _vlun_create_or_use_existing(self, volume, common, host, iscsi_ips,
+                                     target_portals, target_iqns,
+                                     target_luns, remote_client,
+                                     target_portal_ips,
+                                     existing_vluns, iscsi_ip,
+                                     lun_id, port):
+        vlun = None
+        # check for an already existing VLUN matching the
+        # nsp for this iSCSI IP. If one is found, use it
+        # instead of creating a new VLUN.
+        for v in existing_vluns:
+            portPos = common.build_portPos(
+                iscsi_ips[iscsi_ip]['nsp'])
+            if v['portPos'] == portPos:
+                vlun = v
+                break
+        else:
+            vlun = common.create_vlun(
+                volume, host, iscsi_ips[iscsi_ip]['nsp'],
+                lun_id=lun_id, remote_client=remote_client)
+
+            # This function is called multiple times (from a for loop).
+            # We want to use the same LUN ID for every port.
+            # For first port, lun_id is received as None.
+            # - assign lun_id = vlun['lun'] and return it.
+            # Thus for subsequent ports, that same lun_id is used
+            # in create_vlun() above.
+            if lun_id is None:
+                lun_id = vlun['lun']
+
+        iscsi_ip_port = "%s:%s" % (
+            iscsi_ip, iscsi_ips[iscsi_ip]['ip_port'])
+        target_portals.append(iscsi_ip_port)
+        target_iqns.append(port['iSCSIName'])
+        target_luns.append(vlun['lun'])
+
+        return lun_id
+
     def _initialize_connection_common(self, volume, connector, common,
                                       host, iscsi_ips, ready_ports,
                                       target_portals, target_iqns, target_luns,
@@ -254,30 +306,30 @@ class HPE3PARISCSIDriver(hpebasedriver.HPE3PARDriverBase):
         for port in ready_ports:
             iscsi_ip = port['IPAddr']
             if iscsi_ip in target_portal_ips:
-                vlun = None
-                # check for an already existing VLUN matching the
-                # nsp for this iSCSI IP. If one is found, use it
-                # instead of creating a new VLUN.
-                for v in existing_vluns:
-                    portPos = common.build_portPos(
-                        iscsi_ips[iscsi_ip]['nsp'])
-                    if v['portPos'] == portPos:
-                        vlun = v
-                        break
-                else:
-                    vlun = common.create_vlun(
-                        volume, host, iscsi_ips[iscsi_ip]['nsp'],
-                        lun_id=lun_id, remote_client=remote_client)
+                lun_id = (
+                    self._vlun_create_or_use_existing(
+                        volume, common, host, iscsi_ips,
+                        target_portals, target_iqns,
+                        target_luns, remote_client,
+                        target_portal_ips,
+                        existing_vluns, iscsi_ip,
+                        lun_id, port))
 
-                    # We want to use the same LUN ID for every port
-                    if lun_id is None:
-                        lun_id = vlun['lun']
+            if 'iSCSIVlans' in port:
+                for vip in port['iSCSIVlans']:
+                    iscsi_ip = vip['IPAddr']
+                    if iscsi_ip in target_portal_ips:
+                        LOG.debug("vlan ip: %(ip)s", {'ip': iscsi_ip})
+
+                        lun_id = (
+                            self._vlun_create_or_use_existing(
+                                volume, common, host, iscsi_ips,
+                                target_portals, target_iqns,
+                                target_luns, remote_client,
+                                target_portal_ips,
+                                existing_vluns, iscsi_ip,
+                                lun_id, port))
 
-                iscsi_ip_port = "%s:%s" % (
-                    iscsi_ip, iscsi_ips[iscsi_ip]['ip_port'])
-                target_portals.append(iscsi_ip_port)
-                target_iqns.append(port['iSCSIName'])
-                target_luns.append(vlun['lun'])
             else:
                 LOG.warning("iSCSI IP: '%s' was not found in "
                             "hpe3par_iscsi_ips list defined in "
