@@ -26,7 +26,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import units
 import paramiko
-import six
 
 from cinder.common import constants
 from cinder import context
@@ -950,8 +949,7 @@ class GPFSDriver(driver.CloneableImageVD,
 
         return {'provider_location': None}, True
 
-    def copy_image_to_volume(self, context, volume, image_service, image_id,
-                             disable_sparse=False):
+    def copy_image_to_volume(self, context, volume, image_service, image_id):
         """Fetch the image from image_service and write it to the volume.
 
         Note that cinder.volume.flows.create_volume will attempt to use
@@ -968,8 +966,7 @@ class GPFSDriver(driver.CloneableImageVD,
         image_utils.fetch_to_raw(context, image_service, image_id,
                                  self.local_path(volume),
                                  self.configuration.volume_dd_blocksize,
-                                 size=volume['size'],
-                                 disable_sparse=disable_sparse)
+                                 size=volume['size'])
         self._resize_volume_file(volume, volume['size'])
 
     def _resize_volume_file(self, volume, new_size):
@@ -1150,7 +1147,7 @@ class GPFSDriver(driver.CloneableImageVD,
         except processutils.ProcessExecutionError as e:
             msg = (_('Failed to create consistency group: %(cgid)s. '
                      'Error: %(excmsg)s.') %
-                   {'cgid': group['id'], 'excmsg': six.text_type(e)})
+                   {'cgid': group['id'], 'excmsg': str(e)})
             LOG.error(msg)
             raise exception.VolumeBackendAPIException(data=msg)
 
@@ -1160,7 +1157,7 @@ class GPFSDriver(driver.CloneableImageVD,
         except processutils.ProcessExecutionError as e:
             msg = (_('Failed to link fileset for the share %(cgname)s. '
                      'Error: %(excmsg)s.') %
-                   {'cgname': cgname, 'excmsg': six.text_type(e)})
+                   {'cgname': cgname, 'excmsg': str(e)})
             LOG.error(msg)
             raise exception.VolumeBackendAPIException(data=msg)
 
@@ -1170,7 +1167,7 @@ class GPFSDriver(driver.CloneableImageVD,
             msg = (_('Failed to set permissions for the consistency group '
                      '%(cgname)s. '
                      'Error: %(excmsg)s.') %
-                   {'cgname': cgname, 'excmsg': six.text_type(e)})
+                   {'cgname': cgname, 'excmsg': str(e)})
             LOG.error(msg)
             raise exception.VolumeBackendAPIException(data=msg)
 
@@ -1205,7 +1202,7 @@ class GPFSDriver(driver.CloneableImageVD,
             except processutils.ProcessExecutionError as e:
                 msg = (_('Failed to unlink fileset for consistency group '
                          '%(cgname)s. Error: %(excmsg)s.') %
-                       {'cgname': cgname, 'excmsg': six.text_type(e)})
+                       {'cgname': cgname, 'excmsg': str(e)})
                 LOG.error(msg)
                 raise exception.VolumeBackendAPIException(data=msg)
 
@@ -1215,7 +1212,7 @@ class GPFSDriver(driver.CloneableImageVD,
             except processutils.ProcessExecutionError as e:
                 msg = (_('Failed to delete fileset for consistency group '
                          '%(cgname)s. Error: %(excmsg)s.') %
-                       {'cgname': cgname, 'excmsg': six.text_type(e)})
+                       {'cgname': cgname, 'excmsg': str(e)})
                 LOG.error(msg)
                 raise exception.VolumeBackendAPIException(data=msg)
 
