@@ -25,7 +25,6 @@ from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import importutils
 from oslo_utils import units
-import six
 
 from cinder.brick.local_dev import lvm
 from cinder import exception
@@ -377,7 +376,7 @@ class LVMVolumeDriver(driver.VolumeDriver):
                 except processutils.ProcessExecutionError as exc:
                     exception_message = (_("Failed to create thin pool, "
                                            "error message was: %s")
-                                         % six.text_type(exc.stderr))
+                                         % str(exc.stderr))
                     raise exception.VolumeBackendAPIException(
                         data=exception_message)
 
@@ -526,16 +525,14 @@ class LVMVolumeDriver(driver.VolumeDriver):
         escaped_name = self._escape_snapshot(volume['name']).replace('-', '--')
         return "/dev/mapper/%s-%s" % (escaped_group, escaped_name)
 
-    def copy_image_to_volume(self, context, volume, image_service, image_id,
-                             disable_sparse=False):
+    def copy_image_to_volume(self, context, volume, image_service, image_id):
         """Fetch the image from image_service and write it to the volume."""
         image_utils.fetch_to_raw(context,
                                  image_service,
                                  image_id,
                                  self.local_path(volume),
                                  self.configuration.volume_dd_blocksize,
-                                 size=volume['size'],
-                                 disable_sparse=disable_sparse)
+                                 size=volume['size'])
 
     def copy_volume_to_image(self, context, volume, image_service, image_meta):
         """Copy the volume to the specified image."""
@@ -818,7 +815,7 @@ class LVMVolumeDriver(driver.VolumeDriver):
             with excutils.save_and_reraise_exception():
                 LOG.error("Volume migration failed due to "
                           "exception: %(reason)s.",
-                          {'reason': six.text_type(e)}, resource=volume)
+                          {'reason': str(e)}, resource=volume)
                 dest_vg_ref.delete(volume)
         self._delete_volume(volume)
         return (True, None)
