@@ -195,17 +195,20 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
 
     def _find_mapped_lun_igroup(self, path, initiator_list):
         """Find an igroup for a LUN mapped to the given initiator(s)."""
-        initiator_igroups = self.zapi_client.get_igroup_by_initiators(
-            initiator_list)
-        lun_maps = self.zapi_client.get_lun_map(path)
-        if initiator_igroups and lun_maps:
-            for igroup in initiator_igroups:
-                igroup_name = igroup['initiator-group-name']
-                if igroup_name.startswith(na_utils.OPENSTACK_PREFIX):
-                    for lun_map in lun_maps:
-                        if lun_map['initiator-group'] == igroup_name:
-                            return igroup_name, lun_map['lun-id']
-        return None, None
+        igroups = [igroup['initiator-group-name'] for igroup in
+                   self.zapi_client.get_igroup_by_initiators(initiator_list)]
+        # Map igroup-name to lun-id, but only for the requested initiators.
+        lun_map = {v['initiator-group']: v['lun-id']
+                   for v in self.zapi_client.get_lun_map(path)
+                   if v['initiator-group'] in igroups}
+
+        igroup_name = lun_id = None
+        # Give preference to OpenStack igroups, just use the last one if not
+        # present to allow unmapping old mappings that used a custom igroup.
+        for igroup_name, lun_id in lun_map.items():
+            if igroup_name.startswith(na_utils.OPENSTACK_PREFIX):
+                break
+        return igroup_name, lun_id
 
     def _clone_lun(self, name, new_name, space_reserved=None,
                    qos_policy_group_name=None, src_block=0, dest_block=0,
@@ -233,27 +236,14 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
         if len(lun) == 0:
             msg = _("No cloned LUN named %s found on the filer")
             raise exception.VolumeBackendAPIException(data=msg % new_name)
-        clone_meta = self._create_lun_meta(lun[0])
-        self._add_lun_to_table(
-            block_base.NetAppLun('%s:%s' % (clone_meta['Vserver'],
-                                            clone_meta['Path']),
-                                 new_name,
-                                 lun[0].get_child_content('size'),
-                                 clone_meta))
 
-    def _create_lun_meta(self, lun):
-        """Creates LUN metadata dictionary."""
-        self.zapi_client.check_is_naelement(lun)
-        meta_dict = {}
-        meta_dict['Vserver'] = lun.get_child_content('vserver')
-        meta_dict['Volume'] = lun.get_child_content('volume')
-        meta_dict['Qtree'] = lun.get_child_content('qtree')
-        meta_dict['Path'] = lun.get_child_content('path')
-        meta_dict['OsType'] = lun.get_child_content('multiprotocol-type')
-        meta_dict['SpaceReserved'] = \
-            lun.get_child_content('is-space-reservation-enabled')
-        meta_dict['UUID'] = lun.get_child_content('uuid')
-        return meta_dict
+        clone_lun = lun[0]
+        self._add_lun_to_table(
+            block_base.NetAppLun('%s:%s' % (clone_lun['Vserver'],
+                                            clone_lun['Path']),
+                                 new_name,
+                                 clone_lun['Size'],
+                                 clone_lun))
 
     def _get_fc_target_wwpns(self, include_partner=True):
         return self.zapi_client.get_fc_target_wwpns()
@@ -626,25 +616,23 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
     def _move_lun(self, volume, src_ontap_volume, dest_ontap_volume,
                   dest_lun_name=None):
         """Moves LUN from an ONTAP volume to another."""
-        job_uuid = self.zapi_client.start_lun_move(
+        operation_info = self.zapi_client.start_lun_move(
             volume.name, dest_ontap_volume, src_ontap_volume=src_ontap_volume,
             dest_lun_name=dest_lun_name)
-        LOG.debug('Start moving LUN %s from %s to %s. '
-                  'Job UUID is %s.', volume.name, src_ontap_volume,
-                  dest_ontap_volume, job_uuid)
+        LOG.debug('Start moving LUN %s from %s to %s. ',
+                  volume.name, src_ontap_volume,
+                  dest_ontap_volume)
 
         def _wait_lun_move_complete():
-            move_status = self.zapi_client.get_lun_move_status(job_uuid)
-            LOG.debug('Waiting for LUN move job %s to complete. '
-                      'Current status is: %s.', job_uuid,
-                      move_status['job-status'])
+            move_status = self.zapi_client.get_lun_move_status(operation_info)
+            LOG.debug('Waiting for LUN move to complete. '
+                      'Current status is: %s.', move_status['job-status'])
 
             if not move_status:
-                status_error_msg = (_("Error moving LUN %s. The "
-                                      "corresponding Job UUID % doesn't "
-                                      "exist."))
+                status_error_msg = (_("Error moving LUN %s. The movement"
+                                      "status could not be retrieved."))
                 raise na_utils.NetAppDriverException(
-                    status_error_msg % (volume.id, job_uuid))
+                    status_error_msg % (volume.id))
             elif move_status['job-status'] == 'destroyed':
                 status_error_msg = (_('Error moving LUN %s. %s.'))
                 raise na_utils.NetAppDriverException(
@@ -686,29 +674,27 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
                   dest_ontap_volume, dest_vserver, dest_lun_name=None,
                   dest_backend_name=None, cancel_on_error=False):
         """Copies LUN from an ONTAP volume to another."""
-        job_uuid = self.zapi_client.start_lun_copy(
+        operation_info = self.zapi_client.start_lun_copy(
             volume.name, dest_ontap_volume, dest_vserver,
             src_ontap_volume=src_ontap_volume, src_vserver=src_vserver,
             dest_lun_name=dest_lun_name)
         LOG.debug('Start copying LUN %(vol)s from '
                   '%(src_vserver)s:%(src_ontap_vol)s to '
-                  '%(dest_vserver)s:%(dest_ontap_vol)s. Job UUID is %(job)s.',
+                  '%(dest_vserver)s:%(dest_ontap_vol)s.',
                   {'vol': volume.name, 'src_vserver': src_vserver,
                    'src_ontap_vol': src_ontap_volume,
                    'dest_vserver': dest_vserver,
-                   'dest_ontap_vol': dest_ontap_volume,
-                   'job': job_uuid})
+                   'dest_ontap_vol': dest_ontap_volume})
 
         def _wait_lun_copy_complete():
-            copy_status = self.zapi_client.get_lun_copy_status(job_uuid)
-            LOG.debug('Waiting for LUN copy job %s to complete. Current '
-                      'status is: %s.', job_uuid, copy_status['job-status'])
+            copy_status = self.zapi_client.get_lun_copy_status(operation_info)
+            LOG.debug('Waiting for LUN copy job to complete. Current '
+                      'status is: %s.', copy_status['job-status'])
             if not copy_status:
-                status_error_msg = (_("Error copying LUN %s. The "
-                                      "corresponding Job UUID % doesn't "
-                                      "exist."))
+                status_error_msg = (_("Error copying LUN %s. The copy"
+                                      "status could not be retrieved."))
                 raise na_utils.NetAppDriverException(
-                    status_error_msg % (volume.id, job_uuid))
+                    status_error_msg % (volume.id))
             elif copy_status['job-status'] == 'destroyed':
                 status_error_msg = (_('Error copying LUN %s. %s.'))
                 raise na_utils.NetAppDriverException(
@@ -727,7 +713,8 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
         except Exception as e:
             with excutils.save_and_reraise_exception() as ctxt:
                 if cancel_on_error:
-                    self._cancel_lun_copy(job_uuid, volume, dest_ontap_volume,
+                    self._cancel_lun_copy(operation_info, volume,
+                                          dest_ontap_volume,
                                           dest_backend_name=dest_backend_name)
                 if isinstance(e, loopingcall.LoopingCallTimeOut):
                     ctxt.reraise = False
@@ -876,8 +863,6 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
         LOG.info("Cloning LUN %s from snapshot %s in volume %s.", lun_name,
                  snapshot_name, flexvol_name)
 
-        metadata = snapshot_lun.metadata
-
         block_count = self._get_lun_block_count(snapshot_path)
         if block_count == 0:
             msg = _("%s cannot be reverted using clone operation"
@@ -886,12 +871,9 @@ class NetAppBlockStorageCmodeLibrary(block_base.NetAppBlockStorageLibrary,
 
         new_snap_name = "new-%s" % snapshot_name
 
-        self.zapi_client.create_lun(
-            flexvol_name, new_snap_name,
-            six.text_type(snapshot_lun.size), metadata)
         try:
             self._clone_lun(snapshot_name, new_snap_name,
-                            block_count=block_count)
+                            space_reserved='false', is_snapshot=True)
             return new_snap_name
         except Exception:
             with excutils.save_and_reraise_exception():
