@@ -524,8 +524,7 @@ class RemoteFSDriver(driver.BaseVD):
                              context: context.RequestContext,
                              volume: objects.Volume,
                              image_service,
-                             image_id: str,
-                             disable_sparse: bool = False) -> None:
+                             image_id: str) -> None:
         """Fetch the image from image_service and write it to the volume."""
 
         image_utils.fetch_to_raw(context,
@@ -534,8 +533,7 @@ class RemoteFSDriver(driver.BaseVD):
                                  self.local_path(volume),
                                  self.configuration.volume_dd_blocksize,
                                  size=volume.size,
-                                 run_as_root=self._execute_as_root,
-                                 disable_sparse=disable_sparse)
+                                 run_as_root=self._execute_as_root)
 
         # NOTE (leseb): Set the virtual size of the image
         # the raw conversion overwrote the destination file
@@ -889,8 +887,8 @@ class RemoteFSSnapDriverBase(RemoteFSDriver):
                           })
             else:
                 backing_file_template = \
-                    "(%(basedir)s/[0-9a-f]+/)?%" \
-                    "(volname)s(.(tmp-snap-)?[0-9a-f-]+)?%(valid_ext)s$" % {
+                    "(%(basedir)s/[0-9a-f]+/)?" \
+                    "%(volname)s(.(tmp-snap-)?[0-9a-f-]+)?%(valid_ext)s$" % {
                         'basedir': basedir,
                         'volname': volume_name,
                         'valid_ext': valid_ext,
